@@ -1,11 +1,12 @@
 import asyncio
 import time
 from collections import Counter
-from typing import Dict, List, Optional, Tuple
 
 from deprecated.sphinx import versionadded
 
-from .base import MovingWindowSupport, Storage
+import limits.typing
+from limits.aio.storage.base import MovingWindowSupport, Storage
+from limits.typing import Dict, List, Optional, Tuple
 
 
 class LockableEntry(asyncio.Lock):
@@ -31,12 +32,12 @@ class MemoryStorage(Storage, MovingWindowSupport):
     async context
     """
 
-    def __init__(self, uri: Optional[str] = None, **_: Dict) -> None:
-        self.storage: Counter = Counter()
-        self.expirations: Dict = {}
+    def __init__(self, uri: Optional[str] = None, **_: str) -> None:
+        self.storage: limits.typing.Counter[str] = Counter()
+        self.expirations: Dict[str, float] = {}
         self.events: Dict[str, List[LockableEntry]] = {}
-        self.timer: Optional[asyncio.Task] = None
-        super().__init__()
+        self.timer: Optional[asyncio.Task[None]] = None
+        super().__init__(uri, **_)
 
     async def __expire_events(self) -> None:
         for key in self.events.keys():
