@@ -1,12 +1,12 @@
 import urllib
 import warnings
-from typing import Any, List, Optional, Tuple
 
 from deprecated.sphinx import versionchanged
 from packaging.version import Version
 
-from ..errors import ConfigurationError
-from .redis import RedisStorage
+from limits.errors import ConfigurationError
+from limits.storage.redis import RedisStorage
+from limits.typing import Dict, List, Optional, Tuple, Union
 
 
 @versionchanged(
@@ -14,7 +14,7 @@ from .redis import RedisStorage
     reason="""
 Cluster support was provided by the :pypi:`redis-py-cluster` library
 which has been absorbed into the official :pypi:`redis` client. By
-default the :class:`~redis.cluster.RedisCluster` client will be used
+default the :class:`redis.cluster.RedisCluster` client will be used
 however if the version of the package is lower than ``4.2.0`` the implementation
 will fallback to trying to use :class:`rediscluster.RedisCluster`.
 """,
@@ -29,15 +29,14 @@ class RedisClusterStorage(RedisStorage):
     STORAGE_SCHEME = ["redis+cluster"]
     """The storage scheme for redis cluster"""
 
-    DEFAULT_OPTIONS = {
+    DEFAULT_OPTIONS: Dict[str, Union[float, str, bool]] = {
         "max_connections": 1000,
     }
     "Default options passed to the :class:`~redis.cluster.RedisCluster`"
 
     DEPENDENCIES = {"redis": Version("4.2.0"), "rediscluster": Version("2.0.0")}
-    FAIL_ON_MISSING_DEPENDENCY = False
 
-    def __init__(self, uri: str, **options):
+    def __init__(self, uri: str, **options: Union[float, str, bool]) -> None:
         """
         :param uri: url of the form
          ``redis+cluster://[:password]@host:port,host:port``
@@ -57,45 +56,47 @@ class RedisClusterStorage(RedisStorage):
         self.__pick_storage(cluster_hosts, **{**self.DEFAULT_OPTIONS, **options})
         assert self.storage
         self.initialize_storage(uri)
-        super(RedisStorage, self).__init__()
+        super(RedisStorage, self).__init__(uri, **options)
 
-    def __pick_storage(self, cluster_hosts: List[Tuple[str, int]], **options: Any):
-        redis_py = self.dependencies["redis"]
-        if redis_py:
+    def __pick_storage(
+        self, cluster_hosts: List[Tuple[str, int]], **options: Union[float, str, bool]
+    ) -> None:
+        try:
+            redis_py = self.dependencies["redis"].module
             startup_nodes = [redis_py.cluster.ClusterNode(*c) for c in cluster_hosts]
             self.storage = redis_py.cluster.RedisCluster(
                 startup_nodes=startup_nodes, **options
             )
             self.using_redis_py = True
             return
+        except ConfigurationError:
+            self.__use_legacy_cluster_implementation(cluster_hosts, **options)
+            if not self.storage:
+                raise ConfigurationError(
+                    (
+                        "Unable to find an implementation for redis cluster"
+                        " Cluster support requires either redis-py>=4.2 or"
+                        " redis-py-cluster"
+                    )
+                )  # pragma: no cover
 
-        self.__use_legacy_cluster_implementation(cluster_hosts, **options)
-
-        if not self.storage:
-            raise ConfigurationError(
-                (
-                    "Unable to find an implementation for redis cluster"
-                    " Cluster support requires either redis-py>=4.2 or"
-                    " redis-py-cluster"
-                )
-            )  # pragma: no cover
-
-    def __use_legacy_cluster_implementation(self, cluster_hosts, **options):
-        redis_cluster = self.dependencies["rediscluster"]
-        if redis_cluster:
-            warnings.warn(
-                (
-                    "Using redis-py-cluster is deprecated as the library has been"
-                    " absorbed by redis-py (>=4.2). The support will be eventually "
-                    " removed from the limits library and will no longer be tested "
-                    " against beyond limits version: 2.6. To get rid of this warning, "
-                    " uninstall redis-py-cluster and ensure redis-py>=4.2.0 is installed"
-                )
-            )
-            self.storage = redis_cluster.RedisCluster(
-                startup_nodes=[{"host": c[0], "port": c[1]} for c in cluster_hosts],
-                **options
+    def __use_legacy_cluster_implementation(
+        self, cluster_hosts: List[Tuple[str, int]], **options: Union[float, str, bool]
+    ) -> None:
+        redis_cluster = self.dependencies["rediscluster"].module
+        warnings.warn(
+            (
+                "Using redis-py-cluster is deprecated as the library has been"
+                " absorbed by redis-py (>=4.2). The support will be eventually "
+                " removed from the limits library and will no longer be tested "
+                " against beyond limits version: 2.6. To get rid of this warning, "
+                " uninstall redis-py-cluster and ensure redis-py>=4.2.0 is installed"
             )
+        )
+        self.storage = redis_cluster.RedisCluster(
+            startup_nodes=[{"host": c[0], "port": c[1]} for c in cluster_hosts],
+            **options
+        )
 
     def reset(self) -> Optional[int]:
         """
